@@ -1,4 +1,3 @@
-from __future__ import annotations
 import pandas as pd
 import numpy as np
 from typing import List, Dict, Union
@@ -124,7 +123,7 @@ class FeatureSelectTransformer(BaseEstimator, TransformerMixin):
         assert len(col)==1, 'Only one feature accepted'
         self.col = col
 
-    def fit(self, X:pd.DataFrame, y:pd.DataFrame=None)->FeatureSelectTransformer:
+    def fit(self, X:pd.DataFrame, y:pd.DataFrame=None):
         return self
 
     def transform(self, X:pd.DataFrame, y:pd.DataFrame=None)->pd.DataFrame:
@@ -139,7 +138,7 @@ class ToTypeTransformer(BaseEstimator, TransformerMixin):
         self.type=type
         self.date_format=date_format
 
-    def fit(self, X:pd.DataFrame, y:pd.DataFrame=None)->ToTypeTransformer:
+    def fit(self, X:pd.DataFrame, y:pd.DataFrame=None):
         return self
 
     def transform(self, X:pd.DataFrame, y:pd.DataFrame=None)->pd.DataFrame:
@@ -157,7 +156,7 @@ class ToOrdinalTransformer(BaseEstimator, TransformerMixin):
     def __init__(self, mapping_dict:Dict={}):
         self.mapping_dict=mapping_dict.copy()
 
-    def fit(self, X:pd.DataFrame, y:pd.DataFrame=None)->ToOrdinalTransformer:
+    def fit(self, X:pd.DataFrame, y:pd.DataFrame=None):
         X=X.copy()
         if not self.mapping_dict:
             assert X.shape[1]==1, 'Transformer support only one column'
